---
name: Bug Report
about: Create a report to help us improve

---

# Description

Describe your bug here

# Expected Behavior

Describe what you thought should have happened

# Actual Behavior

Describe what did happen

# Steps to Reproduce

Detail your environment and `pyhf.__version__` and the commands that you are executing to generate the bug. If you have a large program please make a [Gist](https://gist.github.com/) and link it here. Additionally attach any screen shots as needed.

# Checklist

- [ ] Run `git fetch` to get the most up to date version of `master`
- [ ] Searched through existing Issues to confirm this is not a duplicate issue
- [ ] Filled out the Description, Expected Behavior, Actual Behavior, and Steps to Reproduce sections above or have edited/removed them in a way that fully describes the issue
